@@ -17,18 +17,20 @@ def cli(image_name, port):
     click.echo('Generating Dockerfile...')
     if (app_type == 'JAVA_SPRING_BOOT'):
         if (not os.path.exists('target')):
-            click.echo('here in 19')
-            click.Abort('No target/ present')
-            click.echo('here in 22')
+            click.echo('here in 20')
+            click.echo('No target/ present')
+            exit(1)
+            click.echo('here in 23')
         found_file = ''
         for filename in os.listdir('target/'):
             if re.search('.*\.jar', filename):
                 found_file = filename
                 break
         if(found_file == ''):
-            click.echo('here in 27')
-            click.Abort('No jar file present. Make sure your target/ contains a jar file')
-            click.echo('here in 31')
+            click.echo('here in 30')
+            click.echo('No jar file present. Make sure your target/ contains a jar file')
+            exit(1)
+            click.echo('here in 33')
         text = pkgutil.get_data(__name__, "templates/Java.Dockerfile").decode()
     open("Dockerfile", "w").writelines([l for l in text])
     click.echo('Dockerfile generated')
